package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````;"````````!``````````,"A````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&N@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````D)4`````
M``"0E0`````````0`````````0````8```"`FP```````("K````````@*L`
M``````#0!````````/@$`````````!`````````"````!@```)B;````````
MF*L```````"8JP```````"`"````````(`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0````PC@```````#".````````,(X```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````@)L```````"`
MJP```````("K````````@`0```````"`!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`"4_?U7F7&^21T*0BKG\+GJ<(M'<!````!`````!````1TY5```````$````
M#P`````````[````1@````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``HA&````1P```$@```!*````````````````````2P``````
M``!,````3@```$\``````````````%````!1````````````````````````
M`%(```!3````5`````````!5````5@``````````````5P````````!8````
M````````````````60```%H`````````7`````````!=`````````%X`````
M``````````````````````````````!?````````````````````8```````
M``!A````````````````````8P```!E^"H=_J9R;:@E#UC_/TFPA_^0.#3J7
M"W)0G]C#Y3\LB0=PT]EQ6!RM2^/`:QJ>4-5DU'R93\.;+\6;MC-BV^W_8?)A
M:W^:?+OCDGRS`8MO0OK7AT-%U>QGK\QF%8PES*/@^TG/WD<MXT?&`>"G`@IO
MQ=\?^Z%L8````````````````````````````````````````````P`,`.`>
M``````````````````#4`@``$0````````````````````````"2`@``$@``
M``````````````````````!Q`0``$@````````````````````````"%````
M$@````````````````````````#Y`0``$@````````````````````````!Y
M`@``$@````````````````````````"V`0``$@``````````````````````
M``"N````$@````````````````````````!R`@``$@``````````````````
M``````"D````$@`````````````````````````U`@``$@``````````````
M``````````##`0``$@````````````````````````!]````$0``````````
M``````````````"5````$@````````````````````````"=`0``$@``````
M``````````````````#$`@``$@````````````````````````#I`0``$@``
M```````````````````````A`0``$@````````````````````````".`0``
M$@````````````````````````#3````$@````````````````````````##
M````$@````````````````````````!8````$@``````````````````````
M```!````(``````````````````````````8`0``$@``````````````````
M``````"J`@``$@`````````````````````````=````(```````````````
M``````````".````$@````````````````````````#*````$@``````````
M``````````````"<`@``$@````````````````````````!<`0``$@``````
M``````````````````![````$0````````````````````````#9````%@``
M``````````````````````!5`0``$@````````````````````````#L````
M$@````````````````````````!X`0``$@````````````````````````!(
M`@``$@````````````````````````"O`0``$@``````````````````````
M```'`0``$@````````````````````````"U`@``$@``````````````````
M``````"B`0``$@`````````````````````````V`0``$@``````````````
M``````````"7`@``$@````````````````````````!%`0``$@``````````
M``````````````!C`0``$@````````````````````````"]`0``$@``````
M``````````````````"$`@``$@````````````````````````!J`0``$@``
M```````````````````````O`0``$@````````````````````````"'`0``
M$0`````````````````````````:`@``$@````````````````````````!_
M`0``$@````````````````````````"-````$@``````````````````````
M``!)````(@`````````````````````````%`@``$@``````````````````
M``````!-`0``$@````````````````````````"J`0``$@``````````````
M``````````#-`@``$@````````````````````````!F`@``$@``````````
M``````````````#4`0``$@````````````````````````"7`P``$@``````
M``````````````````!9`@``$0````````````````````````"U````$@``
M``````````````````````#\````$@`````````````````````````F`@``
M$@`````````````````````````W````$@````````````````````````"<
M````$@````````````````````````!J````$@``````````````````````
M``#B`0``$@````````````````````````#C`P``$`#Q_P"X````````````
M``````"%`P``$@`,`)Q!````````&`````````#'`P``$``5``"P````````
M``````````#4`P``$``5``"P``````````````````!8!```$@`,`'`Y````
M````U@$```````#)`P``(``5``"P````````````````````!```$``5`%"P
M```````````````````0!```$@`,`(@X````````*`````````!E!```$0`5
M`$BP````````"``````````8!```$``6`%"P``````````````````"X`P``
M$0`-`+A,````````!`````````![`P``$@`,`/I*````````L@$````````U
M`P``$@`,`%Q'````````R@$```````!O!```$@`,`!!`````````1```````
M```7`P``$@`,`&XY`````````@````````#-`P``$@`,`&P@````````(@``
M``````"L`P``$``6`'BP``````````````````!$````$@`,`.`>````````
MC`$````````M!```$``6`'BP``````````````````!+`P``$@`,`,(_````
M````3@````````#U`P``$@`,`!Y*````````W``````````_!```$``5`%"P
M``````````````````!O`P``$@`,`&@[`````````@$````````D!```$@`,
M`,I)````````5`````````!W!```$@`,`&H\````````6`,````````R!```
M$@`,`'1"````````Z`0````````H`P``$@`,`$8[````````(@````````!9
M`P``$@`,`+`X````````O@````````"@`P``$@`,`"9)````````I```````
M``!&!```$@`,`+1!````````P```````````7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C7W-T
M87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S
M=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S
M<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI
M;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN
M84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`
M4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`;65M;6]V90!R
M96%L;&]C`&=E='!I9`!M96UC<'D`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R
M8VUP`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV
M-`!R96%D`&UE;6-M<`!G971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?
M7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?
M9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?
M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T
M9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R
M;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S
M960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT
M97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`
M+W5S<B]L:6(O<&5R;#4O-2XS."]C;W)E7W!E<FPO0T]210```````@`!``,`
M`P`!``$``P`#``,``P`!``,``P`#``,``0`!``$``P`#``,``P`!``,``0`!
M``0``P`!``,``P`!``,``0`#``$``P`!``$``P`!``,``P`#``,``0`#``,`
M`P`!``,`!``#``$``P`#``,``0`#``,``0`#``$``0`%``,``P`#``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``P#Q`@``$````$````"TD98&```%`(0$```0````LY&6
M!@``!`"/!```$````(>1E@8```,`F@0````````!``$`^P(``!``````````
MAY&6!@```@":!````````("K`````````P````````".(````````(BK````
M`````P`````````B(0```````)"K`````````P````````#H(````````*"O
M`````````P````````!<1P```````/"O`````````P````````!(L```````
M`/BO`````````P````````#@'@````````"P`````````P``````````L```
M`````!BP`````````P`````````83@```````""P`````````P````````#P
MC0```````"BP`````````P````````#XC0```````#"P`````````P``````
M````C@```````#BP`````````P`````````(C@```````$BP`````````P``
M``````"`4````````)"O`````````@````(``````````````)BO````````
M`@````P``````````````*BO`````````@````X``````````````+"O````
M`````@```!@``````````````+BO`````````@```!L``````````````,"O
M````````"P```"$``````````````,BO`````````@```",`````````````
M`-"O`````````@```"4``````````````-BO`````````@```#(`````````
M`````."O`````````@```#8``````````````.BO`````````@```#X`````
M`````````,BM````````!0````,``````````````-"M````````!0````0`
M`````````````-BM````````!0````4``````````````."M````````!0``
M``8``````````````.BM````````!0````<``````````````/"M````````
M!0````@``````````````/BM````````!0````D```````````````"N````
M````!0````H```````````````BN````````!0````L``````````````!"N
M````````!0````T``````````````!BN````````!0````\`````````````
M`""N````````!0```!```````````````"BN````````!0```!$`````````
M`````#"N````````!0```!(``````````````#BN````````!0```!,`````
M`````````$"N````````!0```!0``````````````$BN````````!0```!4`
M`````````````%"N````````!0```!8``````````````%BN````````!0``
M`!<``````````````&"N````````!0```!D``````````````&BN````````
M!0```!H``````````````'"N````````!0```!P``````````````'BN````
M````!0```!T``````````````("N````````!0```!X``````````````(BN
M````````!0```!\``````````````)"N````````!0```"(`````````````
M`)BN````````!0```"0``````````````*"N````````!0```"8`````````
M`````*BN````````!0```"<``````````````+"N````````!0```"@`````
M`````````+BN````````!0```"D``````````````,"N````````!0```"H`
M`````````````,BN````````!0```"L``````````````-"N````````!0``
M`"P``````````````-BN````````!0```"T``````````````."N````````
M!0```"X``````````````.BN````````!0```"\``````````````/"N````
M````!0```#```````````````/BN````````!0```#$```````````````"O
M````````!0```#,```````````````BO````````!0```#0`````````````
M`!"O````````!0```#4``````````````!BO````````!0```#<`````````
M`````""O````````!0```#@``````````````"BO````````!0```#D`````
M`````````#"O````````!0```#H``````````````#BO````````!0```#L`
M`````````````$"O````````!0```#P``````````````$BO````````!0``
M`#T``````````````%"O````````!0```#\``````````````%BO````````
M!0```$```````````````&"O````````!0```$$``````````````&BO````
M````!0```$(``````````````'"O````````!0```$,``````````````'BO
M````````!0```$0``````````````("O````````!0```$4`````````````
M`)>3```S`\-!`[Z#)Q,#0_V3@H,G$U,3`(.R@@!G``X`%YX```,^CB9G`PX`
M$P```!>>```#/@XF9P,.`!,````7G@```SZ.)6<##@`3````%YX```,^#B5G
M`PX`$P```!>>```#/HXD9P,.`!,````7G@```SX.)&<##@`3````%YX```,^
MCB-G`PX`$P```!>>```#/@XC9P,.`!,````7G@```SZ.(F<##@`3````%YX`
M``,^#B)G`PX`$P```!>>```#/HXA9P,.`!,````7G@```SX.(6<##@`3````
M%YX```,^CB!G`PX`$P```!>>```#/@X@9P,.`!,````7G@```SZ.'V<##@`3
M````%YX```,^#A]G`PX`$P```!>>```#/HX>9P,.`!,````7G@```SX.'F<#
M#@`3````%YX```,^CAUG`PX`$P```!>>```#/@X=9P,.`!,````7G@```SZ.
M'&<##@`3````%YX```,^#AQG`PX`$P```!>>```#/HX;9P,.`!,````7G@``
M`SX.&V<##@`3````%YX```,^CAIG`PX`$P```!>>```#/@X:9P,.`!,````7
MG@```SZ.&6<##@`3````%YX```,^#AEG`PX`$P```!>>```#/HX89P,.`!,`
M```7G@```SX.&&<##@`3````%YX```,^CA=G`PX`$P```!>>```#/@X79P,.
M`!,````7G@```SZ.%F<##@`3````%YX```,^#A9G`PX`$P```!>>```#/HX5
M9P,.`!,````7G@```SX.%6<##@`3````%YX```,^CA1G`PX`$P```!>>```#
M/@X49P,.`!,````7G@```SZ.$V<##@`3````%YX```,^#A-G`PX`$P```!>>
M```#/HX29P,.`!,````7G@```SX.$F<##@`3````%YX```,^CA%G`PX`$P``
M`!>>```#/@X19P,.`!,````7G@```SZ.$&<##@`3````%YX```,^#A!G`PX`
M$P```!>>```#/HX/9P,.`!,````7G@```SX.#V<##@`3````%YX```,^C@YG
M`PX`$P```!>>```#/@X.9P,.`!,````7G@```SZ.#6<##@`3````%YX```,^
M#@UG`PX`$P```!>>```#/HX,9P,.`!,````7G@```SX.#&<##@`3````%YX`
M``,^C@MG`PX`$P```!>>```#/@X+9P,.`!,````=<8;LIN2JAZ+HRN!._)>4
M``"#M"0*+N@RY`P(,`!H"#[.G&`^](%'[_"?^!>6```#-L8(LH47E0```S6E
M"^\@\%B7EP``@[=G#(/'!P#YSY>7``"#MP<)%Y0``!,$!!*2EYAC<DF#1Z=+
M&P5)``X%D^<W`",-]TKO\)_NPF67EP``@[<G"9ACD&'R1QCI$.$7-P``$P>'
M$!<V```3!H8/&.T(Y!#E!4<-*:J&8UGW#!N(-P!"AJ$%$4>(89,7-P"VEP4G
MB..A!>,9!_^;!P8`C@<(;+:7`4=*AI<5``"3A05>([`'`._PO[T]Q0ALDPE!
M`N_P_]PJB<Z%%S4``!,%Y=SO$,`Z*<T(;._P?[?O\#_.(G><8+F/`4>]Y^9@
M1F2F9.)Y2H4&:25A@H#O\%_)%Y0``!,$A`0(["'%[_!?T9>7``"#MP?ZA68S
MAT<`&&,VER,'!YHIMPAL[_!_OGFW"&@!Q>\@,`Y%M\Z%%S4``!,%1<[O$*`S
M".A9U>6WD4>!OP5%[_#?NN_PG^7O`"`"JH<7E0```S5E^()E,``3<0'_@48!
M1PJ([_"?X0*0EY$``).!(7>"@```%Y4``!,%9?N7EP``DX?G^F.(IP"7EP``
M@[<G\)'#@H>"@!>5```3!47YEY4``).%Q?B)C9/7-4#]D;Z5A869Q9>7``"#
MM^?MD<."AX*`01$BX!>4```3!$3V@T<$``;DA>.7EP``@[='[I''%Y4```,U
MI>^"E^_PO_B%1R,`]`"B8`)D00&"@&F_$P$!U",X@2HC/!$J(S21*B,P(2LC
M/#$I(SA!*1>4```#-`3E-`#!;GU?'&`C-/$H@4>3"(4#DP*%!S:($U\/`K</
M_P"3C@[P`[8(`$$(H0B3508"$Q>&`9,3A@"35X8"$UZ&`)-4A@,3DX4!,W?G
M`;/S\P&S]]<!,V=W`#-^W@'%CS-SXP&B!3-GQP$;5H8!L^=G`+/U]0%1C\V/
M(SCH_B,\^/[CDA+[_57&?V9_"F?B;@)^(G/">&)XAF.3A`8@@9$1H+*#L&*<
M8KJ"H0:QC[/']P&SQ]<!$Y<7`/V#78]MC[C^^H_RCA:/&HY&@\*('HCCF9;\
M@SX%`*)O`S@%`0,SA0"#.(4!`SX%`C>'@EH3!Y>9D]>^`1.67@!=CKJ?$U\C
M`),7XP%MCO*?LT88`;/GYP&S]F8`?I;";S/_MP"SQA8!-I:S1N@!;8ZS]M8!
MNI^3$E8`DU2V`<:?L\8&`?Z6L^^2`!/9+@"3D^X!_I;B;[/C(P&SQW<`\8^Z
MG^V.L\?G`<*?DY16`!/9M@&3$N8!_I<)@H)_L^+"`#/F)`&RES/&4P"ZG[/S
MLP!UCNV/?I\S1G8`DY17`!/9MP&3G^8!>I:)@B)_L^_?`+/F)`$VEK/&\@%M
MCK/RL@#]CCJ?'I^3%%8`$UFV`;/&5@"3D^<!B8.SX_,`^I:SYR0!OI8S_[8`
MPG:SQW\`\8^S_[\`NI:6EI,47P`36;\!L\?W`;:7L^8D`;:7DQ+F`0F"L^+"
M`#/VMP#B=[/&4P"S]N8!L_.S`+J7_I>3%%8`$UFV`;/&=@"^EK/G)`&^EI,?
M[P$37R\`L^_O`3/_M@"&9K/'\@'QC[/RL@"ZEIZ6DQ1?`!-9OP&SQU<`MI>S
MYB0!MI>3$^8!"8*SX\,`,_:W`*9GL\9_`+/VY@&S_[\`NI>6EY,45@`36;8!
ML\;V`;Z6L^<D`;Z6DQ+O`1-?+P"SXN(!,_^V`,9FL\=3`/&/L_.S`+J6_I:3
M%%\`$UF_`;/'=P"VE[/F)`&VEY,?Y@$)@K/OSP`S]K<`YF>SQO(!L_;F`;/R
ML@"ZEYZ7DQ16`!-9M@&SQE8`OI:SYR0!OI:3$^\!$U\O`+/CXP$S_[8`AG:S
MQW\`\8^S_[\`NI:6EI,47P`36;\!L\?W`;:7L^8D`;:7DQ+F`0F"L^+"`#/V
MMP"F=[/&4P"S]N8!L_.S`+J7_I>3%%8`$UFV`;/&=@"^EK/G)`&^EI,?[P$3
M7R\`L^_O`3/_M@#&=K/'\@'QC[/RL@"ZEIZ6DQ1?`!-9OP&SQU<`MI>SYB0!
MMI>3$^8!"8*SX\,`,_:W`.9WL\9_`+/VY@&S_[\`NI>6EY,45@`36;8!L\;V
M`;Z6L^<D`;Z6DQ+O`1-?+P"SXN(!,_^V`(IFL\=3`/&/L_.S`+J6_I:3%%\`
M$UF_`;/'=P"VE[/F)`&VEY,?Y@$)@K/OSP`S]K<`JF>SQO(!L_;F`;/RL@"Z
MEYZ7DU2V`9,35@"SQE8`$QGO`;Z6$U\O`+/GDP#*8S-OZ0&^EK/'[P'MCK/_
MOP"ZD_&/GI*3U+8!L\?W`9.35@"SXY,`EI?J9),2Y@$)@K/BP@">E^V/,T9?
M`+J4,W^_`!/9MP%UCI.35P"FGS-&Y@&SXR,!L_.S`'Z6DY_F`8F"'I:S[]\`
M"GFS=+8`L\;R`?V.L_*R`).35`"3V;0!.IDSQU8`L^8S`9.3YP&)@[/C\P!*
MG[/'?P#MCGJ7L8\J=C,/UP`W]]EN$P<7NK-YOP`3V;D!.I:3EED`%I;MC[/F
M)@&RE^V.OI:3DN0!RG>)@+/BD@`S^;8`,\93`+/_OP"35+D!NI<S3^8!$Q99
M`#-_OP#^ET6.^I=MCCZ6DY_I`>IWD]DI`+/O/P&S=+8`,\_R`;/SLP"3V;0!
MNI<S3]\`DY94`#-_OP">E[/F-@'ZE^V.OI83'^D!CF<362D`,V\O`;/SM@`S
MR>\!L_FR`+J7LT+)`!/9LP$3EE,`L_*R`,Z7,V8F`9:7;8X^EI.2Y`&N9XF`
ML^*2`#-)7P"S=+8`L_F_`+J7LT_9`!/9M`&3EE0`L_^_`,Z7L^8F`?Z7[8Z^
MEI.?XP'.9Y/3(P"S[W\`,\GR`;/SM@"S>;\`NI<S3\D`$]FS`1.64P`S?[\`
MSI<S9B8!^I=MCCZ6$Y_D`>YGB8`S;Y\`,\GO`;-TM@"S^;(`NI>S0MD`$]FT
M`9.65`"S\K(`SI>SYB8!EI?MCKZ6DY+C`8YWD],C`+/B<@`S25\`L_.V`+/Y
MOP"ZE[-/R0`3V;,!$Y93`+/_OP#.ES-F)@'^EVV./I:3G^0!KG>)@+/OGP`S
MR?(!LW2V`+-YOP"ZES-/V0`3V;0!DY94`#-_OP#.E[/F)@'ZE^V.OI83G^,!
MSG>3TR,`,V]_`#/)[P&S\[8`L_FR`+J7LT+)`!/9LP$3EE,`L_*R`,Z7,V8F
M`9:7;8X^EI.2Y`'N=XF`L^*2`#-)7P"S=+8`L_F_`+J7LT_9`!/9M`&3EE0`
ML_^_`,Z7L^8F`?Z7[8Z^EI.?XP&29Y/3(P"S[W\`,\GR`;/SM@"S>;\`NI<S
M3\D`$]FS`1.64P`S?[\`SI<S9B8!^I=MCCZ6$Y_D`;)GB8`S;Y\`,\GO`;-T
MM@"S^;(`NI>S0MD`$]FT`9.65`"S\K(`SI>SYB8!EI?MCKZ6DY+C`=)GD],C
M`+/B<@`S25\`L_.V`+/YOP"ZE[-/R0`3V;,!$Y93`+/_OP#.ES-F)@'^EVV.
M/I:3G^0!\F>)@+/OGP`SR?(!LW2V`+-YOP"ZES-/V0`3V;0!DY94`#-_OP#.
ME[/F)@'ZE^V.OI83G^,!DG>3TR,`,V]_`#/)[P&S\[8`L_FR`+J7LT+)`!/9
MLP$3EE,`L_*R`,Z7,V8F`9:7;8X^EI.2Y`&R=XF`L^*2`#-)7P"S=+8`L_F_
M`+J7LT_9`!/9M`&3EE0`L_^_`,Z7L^8F`?Z7[8Z^EI.?XP'2=Y/3(P"S[W\`
M,_FV`+/#\@&S>;\`NI<SS\,`DU.Y`1,660`S?[\`SI<S9G8`;8[ZES./QP"3
MD^0!\G>)@+/CDP`SQG\`LW2_`+/RL@"ZE[&.[8Z3V;0!EI>3DE0`MI>SYC(!
MMI<3%ND!EF8362D`,V8F`3/)PP"S\K<`L_^_`+-'Z0&ZEI/9L@'^EA.94@"S
M_[<`,VDY`?Z6RI83G^0!B8`S;Y\`-_?&([-TM@#]5_6-MF:!DPH'$P?'S;-_
M_P`S9N8!,_GT`;J6,W96`+/S\P"VDY/9M0$S9B8!$YE5`!Z6LV,Y`1Z6LW/V
M`).6X@%69I/2(@"SYE8`L_+V`#-OWP`S^5\`.I8S?[\`LI23V;,!,V\O`1.9
M4P`FG[-D.0$3EN4!)I^)@?9D38ZS=?8`T8XS?_\`,_FR`+/V=@"ZE/Z4DUF_
M`;/F)@$3&5\`II:S9#D!$YKC`9/?(P"FEI9TLV_Z`;/S_P`S9O8!_8XS^74`
MNI0S=N8!II(S9B8!DY16`!/9M@&SY"0!%I:3&>\!)I837R\`MG0S[^D!LW+_
M`+/O[P%]CC/Y4P"S_]\`NI2S[R\!KI03&58`DUFV`9.5Y@&)@M6-LX:?`+-O
M.0'^EM9_L_3U`#-OOP#]CC/YD@"ZGS-_SP`S;R\!_I,3F58`D]FV`9,?Y@$)
M@K/OSP`S!G\`,V\Y`7J6=G^S\_\`L^7U`7V.,_ET`#J?]8VSY24!^I(3&58`
MDUFV`1.?Y@&)@C-OWP"SAE4`LV4Y`:Z6FF6S<O\`L^_O`?V.,_E3`+J5L__/
M`+/O+P&NE!.95@"3V;8!DQ7F`0F"T8TSAI\`LV\Y`7Z6NF^S]/4`,V^_`'V.
M,_F2`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?`+,&?P`S;SD!^I9:
M;[/S_P"SY?4!_8XS^70`.I_QC;/E)0'ZDA.95@"3V;8!$Q_F`0F",V_/`#.&
M50"S93D!+I;Z9;-R_P"S[^\!?8XS^5,`NI6S_]\`L^\O`:Z4$QE6`)-9M@&3
ME>8!B8+5C;.&GP"S;SD!_I::?[/T]0`S;[\`_8XS^9(`NI\S?\\`,V\O`?Z3
M$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZECI_L_/_`+/E]0%]CC/Y=``Z
MG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E.0&NEMIULW+_`+/O
M[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)@M&-,X:?`+-D.0$F
MEOITL__U`#-OOP!]CC/Y\@$S?]\`NI0S;R\!GI03&58`DUFV`9.3Y@&)@K/C
MTP"S!I\`LV0Y`1YI,__S`+/E=0"FEO&-L_3O`3J9_8X6F<6-DYE6`!/:M@&3
M4B8`DQ3F`<J5/FFSY%0`,^9)`;/R]`"RE3/FDP!UCK/S]0`ZF;-U7P!^F9.9
M4P`3VK,!38Z3WR8`DY7F`4J6L^9)`;/E]0$VEK/FM`"S=/8`7F:S__4`,_GR
M`;/V=@`ZEGJ6L^8F`1.?5``3V;0!,V\O`;*6?FD3EN,!D],C`#-F=@"S<_8`
M^I;1C?V.,_I_`.6-.ID3GU8`D]FV`1:9L^5%`;-B/P'*E1/?)``3F>0!LV3I
M`1Y_L_+R`):518ZS\O0`,_GU`#/Z4P!UCCJ?DUFY`1,760!^GS-F1@&S;S<!
M>I:3F>8!$]\F`#/OZ0&SQN0!L___`*V.-[>8,KYULI\*!Q,'9QVS^?\`D]2Y
M`;J5$Y99`)Z5_8Y%CI,3Z0$362D`L^,C`7V.KI:SA<8`,T9_`#-&]@'>?[/T
M]0`3V;0!NI^3EE0`EI]]CK/F)@']CGZ6-I:3G^D!_G:3V2D`L^\_`3-Y]@"S
MPO,!LWG_`+J6,\^R`)-2N0&3%5D`,W__`,Z6L^55`/J6_8VVE1.?Y`&#-@$@
MB8`S;Y\`L\+O`;/T]0"S\_,`D]FT`;J6L\+"`!.65`"S\O(`GI8S9C8!EI9]
MCC:6DQ+I`8,V@2`362D`L^(B`;-S]@`S25\`L_G_`+J6LT^Y`!/9LP&3E5,`
ML___`,Z6L^4E`?Z6_8VVE9.?Y`&#-@$AB8"S[Y\`,\GR`;/T]0"S>?\`NI8S
M3\D`$]FT`1.65``S?_\`SI8S9B8!^I9]CC:6$Y_C`8,V@2&3TR,`,V]_`#/)
M[P&S<_8`L_GR`+J6LT*Y`!/9LP&3E5,`L_+R`,Z6L^4E`9:6_8VVE9.2Y`&#
M-@$BB8"SXI(`,TE?`+/T]0"S^?\`NI:S3\D`$]FT`1.65`"S__\`SI8S9B8!
M_I9]CC:6DY_C`8,V@2*3TR,`L^]_`#/)\@&S<_8`LWG_`+J6,T^Y`!/9LP&3
ME5,`,W__`,Z6L^4E`?J6_8VVE1.?Y`&#-@$CB8`S;Y\`,\GO`;/T]0"S^?(`
MNI:S0LD`$]FT`1.65`"S\O(`SI8S9B8!EI9]CC:6DY+C`8,V@2.3TR,`L^)R
M`#-)7P"S<_8`L_G_`+J6LT^Y`!/9LP&3E5,`L___`,Z6L^4E`?Z6_8VVE9.?
MY`&#-@$DB8"S[Y\`,\GR`;/T]0"S>?\`NI8S3\D`$]FT`1.65``S?_\`SI8S
M9B8!^I9]CC:6$Y_C`8,V@223TR,`,V]_`#/)[P&S<_8`L_GR`+J6LT*Y`!/9
MLP&3E5,`L_+R`,Z6L^4E`9:6_8VVE9.2Y`&#-@$EB8"SXI(`,TE?`+/T]0"S
M^?\`NI:S3\D`$]FT`1.65`"S__\`SI8S9B8!_I9]CC:6DY_C`8,V@263TR,`
ML^]_`#/)\@&S<_8`LWG_`+J6,T^Y`!/9LP&3E5,`,W__`,Z6L^4E`?J6_8VV
ME1.?Y`&#-@$FB8`S;Y\`,_GU`+/$[P&S^?(`NI:SPL0`DU2Y`1,660"S\O(`
MSI9%CI:6?8XVEI.4XP&#-H$FD],C`+/D=`"S0I\`LW/V`+/Y_P"ZEK//L@"3
MTK,!DY53`+/__P#.EK/E50#]C?Z6LX^V`),2Z0&#-@$G$UDI`+/B(@&SQ50`
M,_G_`#-__P"36;D!NI:QC1,660#]C?J6,V8V`7V.KI:SA<8`$Y_C`0,V@2>3
MTR,`,V]_`+/&X@&S\_4`_8PZEK/&]@']CB:6D]FS`9.44P`VEK/F-`$VEH,V
M`2B3'^D!$UDI`+/O+P&ZEK-$_P$S=_8`]I:S\O(`,\:T`'V.DQ57`)->MP&6
MEK*6,^;5`9.5XP&3TR,`LI:SY74`_8XZDS,&SP$SAP4!LX4?`7V/%.']C;-V
M\P#QCQCI'/$4Y0SM`S>!*!Q@N8\!1X7C@S"!*P,T`2N#-($J`SD!*H,Y@2D#
M.@$I$P$!+(*`[^!_LSEQ!OPB^%G%6N"7AP``@[<'P0.[!P!C`0L(2O!.[%+H
M@T<%`*J)+HHJB1,'T`.ERV.&YP"#1QD`!0G]^SL).4$#-`L`.<PF]%;DVH23
M"M`#2H;.A2*%[^#/^;,')`$)Y8/'!P!C@%<#@&2A!'7PHG0">>)I0FJB:@)K
MXG`BA4)T(6&"@+.$9$&-A`4)(R":`$J4\;\!1-6W`FL!1/F_`4E%MP)YXFE"
M:@)KP;]Q<2+Q)NT&]9>$``"#M.2T+`"<8#[E@4<JA._@WYD-X>)'O6819_6/
M8X7G`"EG8YKG`(E%(H7OX`_Y$S45`!&@`44J9YQ@N8\!1Y'GJG`*=.ID36&"
M@._@'Z,Q<4[M!OV7B0``@[EIKX.W"0`^Y8%'&<4B^8-'!0`JA(GO2G0J9X.W
M"0"YCP%'8Y8'#.IPZFDI88*`)O5*\>_@_YVJA%'))H7OX$_P0<&#1C4!$PDU
M`9N&)OV!YH-&&0#]T@-'-0$;!R?]/<LBA5+I[^#/ZRJ*2H7OX$_K.P6J``DE
M[^"OZ\J'(H>7%@``DX8F>GU6A44JB>_@7Y0L`$J%[^#/]_U78PCU`.)'O681
M9_6/8X#G!$J%[^!/\DJ%[^#_@":%2FKOX&_H4?$FA>_@[_4BA>_@C^]*=*IT
M"GF9MP-'&0`;!R?]4?,#1RD`(=^UOTJ%[_#?\-&W(ODF]4KQ4NGOX+^201$B
MX!>$```#-"2B!N279@``DX8&A[,'1`"(8Q>&```#-B:AEQ4``).%I7#OX+^+
M$I0(8`)DHF`7)P``$P=GJ8%'NH87A@```S8FG)<5``"3A25P00%OX`_S77%6
M[/UWA6K]<N$7$X<*`:+@)OQ*^$[T4O"&Y#Z7%I&NB;,%)P`3AXH`"I<%9!>)
M```#.>F6*HH3!O3_%Q4``!,%!6V#-PD`'..!1^_@#^6;!`4`8UZ0`!.'"@$*
MES,$AT";A_3_/I0#1X3_*>.=[Y>'``"#M\>53H;2A9*7B&/OX,_<A6>A!XJ7
MF&.#-PD`N8\!1[GGA6(6D:9@!F3B=$)YHGD">N)J86&"@+Z$_7<%9^$700<^
MES,$)P`FAI,%\`(BA>_@C_!%U9>'``"#MR>0IH8BAI*7B&/2A>_@#^A5M^_@
MK_X=<:+HIN3*X%+XANQ._%;T6O"#QP4`%XD```,Y"8JJA).'-_R3MQ<`,X3U
M`"*%@S<)`#[D@4?OX`_+*HI,`":%[_!?QWG)JHGOX._)8W9%"Y)*%XL```,[
MRX>."@/'!`"FAY,&T`-C"`<28P;7``/'%P"%!WW[A9^#.0L`$P4J`#Z5UIGO
MX"_'(["I`#'%`S<+`(/'!``3A10`5I<48Q,&T`,C@/8`@>N]H(-'!0`%!:,`
M]P"MPS:'A0;CF,?^DP;0`Y,'%P`C`-<``T<$`(4'!02CC^?^=?LB9X,W"0"Y
MCP%'W>_F8$9DIF0&:>)Y0GJB>@)[)6&"@(-'!`"%"04$HX_Y_O';@T<$`(4)
M!02CC_G^_?/1MS:'7;=>[&+H%WL```,["WL#/`L`@S<,`+7'XH>!29AGSH:A
M!X4I9?^-)I.5-@"7AP``DX>G@YA#%>L%1RZ%F,/OX`^ZJHLQQ9.:.0!6AN*%
M[^`/TR,P>P&;AQD`C@>^FR.P"P#B:T)L3L+QO6*%[^`OVR,PJP"JBPG-DYHY
M`.F_@4?%M<%%@4E=MU[L8NCOX"_DXFM";#6WEW<``(.WAW.75@``DX:&6!=V
M```#-@9SDI>(8Y<5``"3A45";^!/W5UQ)OSY<HEDAN2BX$KX3O03AX0!%I$*
MEY=Y``"#N8EL@[<)`!SC@4?OX(_!_7?!%Y.&!`*^EC.$)@`%9BJ'EQ<``).'
M)T*7%@``DX8F0@4&A44BA>_@S];Y=:$5DX<$`JZ7LX0G`"*%!6:FA>_@3[<;
M!`4``4EC3P0`&P44`._@+ZHJB0')(H:FA4J4[^!/NB,`!`")9^$'BI>88X.W
M"0"YCP%'F>N)8A:1IF!*A09DXG1">:)Y86&"@._@;]6)MX5F_7=1<?URDX='
M]Q.'!@FB\:;MRNEB\8;USN72X5;]6OE>]6;M:ND^EQ:1+H2S!2<`$X>&"`J7
M%WP```,\C%XJB8,W#``<XX%'%Q4``!,%93?O\-^<JH23!?`"2H7OX"^[(<47
M%0``$P7%-LJ%[_#?STJ%A6>3AX<(BI>88X,W#`"YCP%'8Y8'%(5B%I&N<`YT
M[F1.::YI#FKJ>DI[JGL*?.IL2FUM88*`(H7OX$^YEQ4``).%!3/OX(^4*H1=
MT85G_7GA&1.'!PE.E[,))P`3AP<)DX<'"8J7A6I]>K.,5T&#1P0`$PJ*]U*7
MEQL``).+RR\7&P``$PO++S,*)P#)RY'$HH4FA>_@CZ@UQ2*%[^`/E),']?^B
MERJ-DP;P`F-H]``QJ".`!P#]%V,&]``#QP<`XPG7_B*%[^!OD2J-2H7OX.^0
M:I4%!>-]5?&%14J(WH<BA]J&!69.A>_@3[K2A4Z%[^#/G0'I@Z>,^+UF(6?U
MCV./YP*7%0``DX6%)@%%[^#OARJ$XPX%[(-'!`"M^Y'$@\<$`)N')_V9QP5-
M%Q0``!,$A"%AOX/'%`#IU_VWA45.A>_@KXU=_<Z%%Q4``!,%)2'O\%^Z3H7O
MX$^G5;7OX.^W01&3!?`"(N`&Y"J$[^#OJ!G!$P05`"*%`F2B8$$!;^#/I'EQ
MA6?]<DKH!O0B\";L$X>'`!:1%WD```,Y24$*EX,W"0`<XX%'3<&#1P4`JH3)
MS^_@CX(3!A4`A6<JA&/OQPI]=V$7P0>ZES.')P"FA3J%[^"/DI,']/^JEY,&
M\`)C:/4`$:@C@`<`_1=CAJ<``\<'`.,)U_Y]=85G817!!ZJ7,X0G`),%\`(B
MA>_@[YX-S6-BI`9]=85G817!!ZJ7,X4G`._@;YJ%9Z$'BI>88X,W"0"YCP%'
MH>>%8A:1HG`"=.)D0FE%88*`A6>A!XJ7F&.#-PD`N8\!1YWCA6(6D:)P`G3B
M9$)I%Q4``!,%I0U%86_@CY4C``4`<;\!16VW[^"OI3EQ(O@F]$KP3NP&_)=T
M``"#M*0QG&`^Y(%'0``7&0``$PDI#I=Y``"#N:DQHH5*A>_P3^\5P1)'@[<)
M``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\"_M9?$7&0``$PEI"Y=Y``"#N>DM
MHH5*A>_PC^L5P1)'@[<)``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\&_I9?$7
M&0``$PDI")=Y``"#N2DJHH5*A>_PS^<5P1)'@[<)``X'NI>89YCC9=>8:Z$'
MF.-M_Z*%2H7O\*_E9?$7&0``$PEI!9=Y``"#N6DFHH5*A>_P#^05P1)'@[<)
M``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\._A9?$7&0``$PDI`I=Y``"#N:DB
MHH5*A>_P3^`5P1)'@[<)``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\"_>9?$7
M&0``$PEI_Y=Y``"#N>D>HH5*A>_PC]P5P1)'@[<)``X'NI>89YCC9=>8:Z$'
MF.-M_Z*%2H7O\&_:9?$7&0``$PDI])=Y``"#N2D;HH5*A>_PS]@5P1)'@[<)
M``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\*_69?$7&0``$PGI^)=Y``"#N6D7
MHH5*A>_P#]45P1)'@[<)``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\._29?$7
M&0``$PDI]I=Y``"#N:D3HH5*A>_P3]$5P1)'@[<)``X'NI>89YCC9=>8:Z$'
MF.-M_Z*%2H7O\"_/9?$7&0``$PEI\Y=Y``"#N>D/HH5*A>_PC\T5P1)'@[<)
M``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\&_+9?$7&0``$PDIYI=Y``"#N2D,
MHH5*A>_PS\D5P1)'@[<)``X'NI>89YCC9=>8:Z$'F.-M_Z*%2H7O\*_'9?&B
MA1<5```3!<7L[_"OQJJ%&<47%0``$P7%Z>_P;_JBA1<5```3!67L[_#/Q*J%
M&<47%0``$P7E[._PC_BBA1<5```3!07M[_#OPJJ%!<T7%0``$P6%W._PK_8B
M9YQ@N8\!1ZGC0G3B<*)T`GGB:9<5``"3A87L%Q4``!,%A>`A86_P#_2BA1<5
M```3!87I[_!OOJJ%>=$7%0``$P6%X._P+_)EO^_0/_`!$2+H!NP7=````S2$
M_$P`%Q4``!,%9=X<8#[D@4?O\.^Z%<&#1P4``46)QY.'!_TS-?``(F<<8+F/
M`4>9Y^)@0F0%88*``47UM^_07^L=<0;L*HX7=0```S4E_`AA$P.!`B[T,O@V
M_+[DNN#"Z,;LEW<``(.WY_6:AG*&A4688SKD`4<:X._0G\`3!?`/[]`?O%EQ
MHO#!<D%DSN32X&;LAO2F[,KH5OQ:^%[T8O`3!X0`%I$*EY=\``"#O(SQ@[<,
M`!SC@4<)1H%%*HKOT#_+DPGU_Q/7^4-!D[.'Z0#"%\&3F8^SB?E`8\<)"L%T
MP123!P0!P6NFE_U:LX0G`*$+'4P7>0``$PE)]$%[`4;.A5*%[]#?QF,!50M>
MAJ:%4H7OT/_3`25C"E4'8W.L!F$5,X2D`&-VE`"AJ'T48VJ4!"%&RH4BA>_0
MG\!E^<%W06?!%T$'/I>S!R<`,P7T0$Z5P6>A!XJ7F&.#MPP`N8\!1[WCP6(6
MD:9P!G3F9$9IIFD&:N)Z0GNB>P)\XFQE88*`VIGCG6GW?57AM\%GH0>*EYAC
M@[<,`+F/`4>5YQ<5```3!:7/[_"_Z<%GH0>*EYAC@[<,`+F/`4>9YQ<5```3
M!<7,[_#?Y^_0G])!$0;D[]`?H0$E[]"_RQ'!"&&B8$$!@H`Y<2;T2O`&_!=Y
M```#.4G=JH1,`!<5```3!07+@S<)`#[D@4?O\&^;&<4B^(-'!0`JA)WC0G0B
M9X,W"0"YCP%'IH47%0``$P4ER*WGXG"B=`)Y(6%O\"_-)H5.[._0'YNJB2*%
M[]"?FDZ5"07OT!^;(HB7%P``DX>GLB:'EQ8``).&!K-]5H5%*H3OT#_#(F>#
M-PD`N8\!1Y7CHH5"=.)IXG"B=`)Y%Q4``!,%Y<$A86_P;\<B^$[L[]!?Q>_0
M'\67=P``DX='V0UQ@[@'`0.XAP&0<Y1WF'N<?\KB3OY2^H;NHNH7>@```SJ*
MSP,S"@`:Y@%#%Q,``!,#@[X3"<$!/N&7%P``DX<GOJJ)FN`^]!<3```3`T.F
MEQ<``).'1[W*A1<5```3!:6EFN2"Z,;LPO"R]+;XNOP^^`+\[_#OB1'%@T<%
M`"J$8Y@''J;F5O;OT-^*`27OT'^U8P(%%@!A8P\$%"*%[]!_B@8%!07OT/^*
M`T<$`*J$JHH5PUKR%QL``!,+Z[<FA=J&?5:%1>_0_[(#1Q0`B00%!'7W$GND
M"!<5```3!46L(:"(9*$$#<'*A>_PCX(JA&W9@T<%`/77[_!OC'W1(H7OT%^C
M*H09[80`@&`!S(-'!`!C@`<.(H7O\&^*>>&`9*$$=?0BA>_0_X&JA%:%[]!_
M@:F<FX1$0":%[]"_@=:(EQ<``).'QYD7&```$PA(KR*'EQ8``).&)J]]5H5%
MJHKOT%^IDP4`'%:%[]"_FOU78QCU`._0'X`<045'8YKG#%[NDPN!"-Z%5H7O
MT+^>*H09Y>I'O6819_6/8X'G"I=W``"#M^>[@[8)`(AC5H<7%@``$P9FKH5%
M[]#?H?)K@40R9X,W"@"YCP%'8Y\'+O9@5F2R>A9I\GE2>B:%MF0U88*`(H7O
MT!^5*H2A!.,/!?`5OP%$!;\B=200&<G*A>_@7_$!Q8-'!0"-XXADH01]]35%
M6O+OT`_TJH2JBA<4```3!`2?$P<P!7FU[]"_D"J$:=WOT"_Q!@4%!;6U6O(*
M6^_03^^;!P4`8P;[!!)[@;\7=P```S?'L(.V"0`(8Q<6```3!F:?5H>%1>_0
MOY:!O^_PG\PR9X,W"@"YCP%'8YH')"*%5F3V8!9I\GE2>C5A;]!?BNI'8NH3
M!P`<D_?W'V.%YP`2>U)LW;TFA>_0C^K*A:J$%Q4``!,%A:/OX'_EJH5C#P40
M`[4)`._PK\(JC&,(!1!BA>_0[^8;"P4`C4=CV&<#$P7+_Y<5``"3A<6@8I7O
MT"_Y">V11V,%^QB;![O_XI<#QP<`DP?P`F,,]Q;*A1<5```3!:6"[^"?WV'%
M@T<%`.G#$P<``V..YPJ7%0``DX5EBA<5```3!66`[_`/DN_0+_,JB)<8``"3
MB$BJEP<``).'QWA6AY<6``"3AJ:<?5:%12:%[]#?B'U9Q4D7'```$PS,IY<+
M``"3BTMV%QL``!,+2YLEH._0K]X<06.7-P/OT`_N!20JB&+@HHC>AU:'VH9]
M5H5%)H7OT)^$DP4`'":%[]#O]>,()?U6A>_03_*FA1<%```3!>5N[_`/B2:%
M[_!?MA)[\FM2;,VS`[P)`,6]@45BA>_0OX8JB1W=[_!_GJJ)XTL%\I,%9?\!
M1DJ%[]`/[!,+`0(91MJ%2H7OT"_YF4=C'/4(`E>W1T%#DX<',.,4]_`#5TL`
MD6>3AX=4XQWW[@%&DX7I_$J%[]!/Z!,&@`+>A4J%[]"/]9,'@`)C'O4$EQ@`
M`).(2)E>B)<'``"3AZ=G5H>7%@``DX:&BGU6A44FA2,(`0KOT&_W-;^#N8D`
MXX0)Z$Z%[]!ORXU'X_ZGYG$5EQ4``).%)89.E>_0#][C%`7F3HR-M3)G@S<*
M`+F/`4>1ZQ<5```3!86$[_`?C5KR7NYBZN_0;_>FYE;V6O)>[F+J[]"/]CEQ
M(O@7=````S0$ADKP3NP&_";T4NBS!T0`A&.3"4$`%WD```,Y28&#QP0+SH47
M!0``$P7E8`,W"0`ZY`%'HXCT"N_@'[\9Q0-'!0"3!Q`#8PCW%._PK\NS!T0`
MA&,FA8U&!4:7%0``DX6%@._0C\:JA!W!'&DS!T0`"&.,8Q<&```3!F9_[]#O
MQ9QHC&/<11.7EP)C0P<2LP=$`(ACC48%1I<%``"3A:5][]"OPJJ$%WH``!,*
MRH05P<Z%%P4``!,%A5+OX/^V*H9C``4.G&@S!T0`"&.,8^_0S\"S!T0`A&,%
M1I<%``"3A05Z)H7OT&^TJH47!@``$P:&>B:%[]!OOA*4'&#.A1<%```3!<5,
MHX@'"N_@_[$C.*H`*H0IS9,%`!PBA>_0[]`;!Q4`A4=C]N<"Q4=C`_4"(F>#
M-PD`N8\!1\GC@S>*`*J&(H:,8Q<%```3!<5W[]#/U")G@S<)`+F/`4>EX^)P
M0G2B=`)YXFE":B%A@H`#-8H`[_#?F2,XJ@`JA$G](F>#-PD`N8\!1Y7K%P4`
M`!,%!7'OT(_0@T<5`..-!^IUM0,WB@"<:`QCB&/OX%_.%;>S!T0`B&/OT$_+
MT;WOT._9>7$B\";L!O079````S0D9JJ$3``7!0``$P7E1QQ@/N2!1^_@?Z0!
MS8-'!0")RQ,'``-CAN<`@<2#QP0`F>LB9QQ@N8\!1Z'OHG`"=.)D16&"@":%
M2NCO\,^>DP7P`BJ)[]"OQ1G!$PD5`$J%[]#OP1%&EP4``).%!5+OT`^>&<%"
M:76_(F<<8+F/`4>1ZP)T0FFB<":%XF1%86_@7ZU*Z._0K\]!$1,%``@&Y._0
M[Y^W=EU,-W?I8;<E16>3A14PA@8W5C(0!@<,X9.&YL^710``@[7%01,&9D<3
M!P<?#.44Z1#M&/$C-`4"(S@%`B,L!0:B8$$!@H`Y<2+X)O1*\%;D!OQ.[%+H
M&'63%S8`%'FZEX(7@9,SM^<`JH2ZEBA=$U?6`3:7G/28^#*)+H23BH0#,>V3
M!_`#8]PG"1L)"?P;6FD`FPD:`)H)HIFBA1,&``16A>_0;Z83!`0$)H7OT`_J
MXQ4T_QL::@`["4E!2H;.A5:%[]!OI".L)`?B<$)THG0">>)I0FJB:B%A@H"3
M"0`$NX>I0+Z)8TKV`AN*"0"3BH0#4H:BA5:5[]`/H;Q<$P<`!+N&^0"TW..1
MYOPFA3L).4%2E._0C^.MM[*)^;>BB7&_>7$B\";L4N`&]$KH3N2#N84"$XJ%
M`Y,&`/@3UCD`$W;V`S,'R@`#N04#DP<6`",`UP`3!X`#+H2JA`4F8U?W$A,'
M``01GY%&,P7Z`&-UUQ2)1V-Y]Q)C%`<2(H7OT._<$P:``X%%4H7OT.^LDU8)
M`1-7B0"3]O8/H@:;5XD!$W?W#T('U8\3>?D/8@G9CQO6B0&3U@D!`A:SYR<!
M$]>)`)/V]@^B%M&/$W?W#T(7U8_B&=F/L^<W`3SX(H7OT._6'&`BA>&#(X#T
M`!Q@P8.C@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T`!QDP8.C@O0`'&2A@R.#
M]``<9*.#]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%]``<:*.%]``<;.&#(X;T
M`!QLP8.CAO0`'&RA@R.']``<;*.']``<<.&#(XCT`!QPP8.CB/0`''"A@R.)
M]``<<*.)]``"=*)PXF1"::)I`FI%86_0#Y`3!X`#.P;'0(%%,P7Z`._0[YO%
MO2,`!0#AO2,`!0"C``4`>1<)!>,%!^SMMR,`!0"C``4`(P$%`*,!!0!Q%XE'
M$07C9??JT;^79@``@[9&-6_`W_P!``(``````"5S+R5S````1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5```
M```O<')O8R]S96QF+V5X90``97AE```````O<')O8R\E:2\E<P``````+@``
M``````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`````````
M+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU
M3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#
M2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]4
M35!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.```````````Q`````````&QS965K(&9A:6QE9```
M``!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0051(`%-94U1%30``+W1M
M<`````!54T52`````%5315).04U%```````````E,#)X`````'!A<BT`````
M)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L
M`````"YP87(`````<VAO<G0@<F5A9````````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&```````
M``!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0```````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`5$U01$E2``!414U01$E2`%1%35``````
M5$U0``````")J\WO`````'!E<FQX<VDN8P``````````0T%#2$4```$;`SOL
M````'````+"0__^`!@``/)+__P0!``#TDO__&`$``%ZE__]0`0``"J;__[P!
M``!DIO__Z`$``&JG__]``@``Q*?__V0"``"JJ/__I`(``%BJ__\$`P``@*K_
M_Q@#```^J___4`,``$"K__]D`P``%JW__[@#```XK?__V`,``#JN__\<!```
MDK'__U`$``#@L?__=`0``"2R__^,!```;+/__]P$``"$L___^`0``$2T__],
M!0``++G__P`&``#VNO__.`8``)J[__^T!@``[KO__]0&``#*O/__#`<``'R^
M__](!P```````!```````````WI2``%\`0$;#0(`$````!@````PD?__(@``
M```'`0`T````+````-21__]J$@```$0.P`58B`2!`HD&D@B3"I0,`S`2"L%$
MR$3)1-)$TT341`X`0@L``&@```!D````!J3__ZP`````0@Y`1($"B`1,EA!2
MD@B3"I0,9HD&E0YFR4+20M-"U$+50M9"P43(0@X`0@Y`@0*(!(D&D@B3"I0,
ME0Z6$%#)TM/4U=9$EA!"UD22"),*E`R6$$;20M-"U$+6`"@```#0````1J3_
M_UH`````0@ZP`4:(!(D&@0("1@K!0LA"R4(.`$(+````5````/P```!TI/__
M!@$```!"#L`!1),*@0)8B`1&R%#!0M-"#@!"#L`!@0*(!),*1(D&D@ARE`P"
M5M14"LA"R4+20@M2E`Q(R,G2U$B(!(D&D@B4#````"````!4`0``(J7__UH`
M````0@X00H@$2H$":,A"P5X.`````#P```!X`0``6*7__^8`````0@Y01)4.
M6@[0((@$B0:2"),*E`R!`@)Z"@Y00L%"R$+)0M)"TT+40M5"#@!""P!<````
MN`$``/ZE__^N`0```$(.8%2(!(D&D@B4#($"DPJ5#I80`M`*P4+(0LE"TD+3
M0M1"U4+60@X`0@MNEQ*8%`)6"M="V$0+5-?81)<2F!1&U]A$EQ*8%$;70M@`
M```0````&`(``$RG__\H`````````#0````L`@``8*?__[X`````0@Y01(D&
M4`[00($"B`22"),*`I0*#E!"P43(0LE"TD+30@X`0@L`$````&0"``#FI___
M`@````````!0````>`(``-2G___6`0```$8.\`%F#O`AB`2)!I((F!2!`I,*
ME`R5#I80EQ*9%IH8`F(*#O`!0L%"R$+)0M)"TT+40M5"UD+70MA"V4+:0@X`
M0@L<````S`(``%:I__\B`````$(.$$B(!($"4,A"P4(.`$````#L`@``6*G_
M_P(!````0@XP4@ZP()((@0*(!(D&`J@*#C!"P4+(0LE"TD(.`$(+5@H.,$+!
M0LA"R4+22@X`1`L`,````#`#```6JO__6`,```!"#D!*B`2)!I((DPJ!`@,*
M`PK(0L%"R4+20M-2#@!$"P```"````!D`P``.JW__TX`````0@X@1(@$@0)Z
M"L%"R$(.`$(+`!0```"(`P``9*W__T0`````0@Y@0H$2`$P```"@`P``D*W_
M_T@!````0@YP1(@$7`[P@`23"I0,F1:!`HD&D@B5#I80EQ*8%`+""@YP0L%"
MR$+)0M)"TT+40M5"UD+70MA"V4(.`$(+&````/`#``"(KO__&`````!"#A!"
M@0)0P4(.`%`````,!```A*[__\``````0@Y`1HD&D@B!`FB(!$;(6,%"R4+2
M0@X`1`Y`@0*(!(D&D@A$DPH"0LA"TT+!0LE"TDH.`$0.0($"B0:2"$2(!),*
M`+````!@!```\*[__^@$````2@[@`EJ2"),*E`R!`H@$`FR)!I4.;I808-8"
MK)<2`CS74@K!0LA"U4+20M-"U$3)0@X`0@MR"I805@M2EQ)"EA!0UD+78,G5
M5LA"P4+20M-"U$(.`$0.X`*!`H@$B0:2"),*E`R5#I80EQ),F!1&UD+80I80
MF!0#,`$*UD+70MA""P/H`-;7V$:6$)<2F!1$R=76U]A*B0:5#I80EQ*8%```
M`#0````4!0``)+/__\H!````0@Y`0H@$4I((DPJ!`HD&E`P#5`$*P4+(0LE"
MTD+30M1"#@!""P``1````$P%``"VM/__I`````!"#C!&B`2)!H$"`D(*P4+(
M0LE"#@!""T22"&P*TD(+3,A"TD+!1,E"#@!$#C"!`H@$B09"D@@`,````)0%
M```HBO__C`$```!"#F!,@0*)!H@$D@B3"@,0`0K!0LA"R4+31-)"#@!""P``
M`!P```#(!0``WK3__U0`````0@X01H$"`DC!0@X`````-````.@%```2M?__
MW`````!"#D!.B`2)!I((E0Z!`I,*E`P"=@K!0LA"R4+20M-"U$+50@X`0@LX
M````(`8``+:U__^R`0```$(.,$R(!(D&E`R!`I((DPH#3`$*R$+!0LE"TD+3
M0M1"#@!$"P`````````0````7`8``"RW__\,````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$`````````Y@(````````!`````````/$"`````````0``````
M``#[`@```````!T`````````I00````````@`````````("K````````(0``
M```````(`````````!D`````````B*L````````;``````````@`````````
M&@````````"0JP```````!P`````````"`````````#U_O]O`````-@"````
M````!0````````#0#0````````8`````````<`0````````*`````````,@$
M````````"P`````````8`````````!4````````````````````#````````
M`+BM`````````@````````!`!0```````!0`````````!P`````````7````
M```````6````````!P````````#`$P````````@`````````@`<````````)
M`````````!@`````````'@`````````(`````````/O__V\``````0``"```
M``#^__]O`````&`3````````____;P`````"`````````/#__V\`````F!(`
M``````#Y__]O``````T`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````0!L```````!`&P```````$`;
M````````0!L```````!`&P```````$`;````````0!L```````!`&P``````
M`$`;````````0!L```````!`&P```````$`;````````0!L```````!`&P``
M`````$`;````````0!L```````!`&P```````$`;````````0!L```````!`
M&P```````$`;````````0!L```````!`&P```````$`;````````0!L`````
M``!`&P```````$`;````````0!L```````!`&P```````$`;````````0!L`
M``````!`&P```````$`;````````0!L```````!`&P```````$`;````````
M0!L```````!`&P```````$`;````````0!L```````!`&P```````$`;````
M````0!L```````!`&P```````$`;````````0!L```````!`&P```````$`;
M````````0!L```````!`&P```````$`;````````0!L```````!`&P``````
M`$`;````````0!L```````!`&P```````)BK````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1TY5*2`Q,RXR+C$@,C`R,S`X,#$`05(```!R:7-C=@`!2`````00
M!7)V-C1I,G`Q7VTR<#!?83)P,5]F,G`R7V0R<#)?8S)P,%]Z:6-S<C)P,%]Z
M:69E;F-E:3)P,%]Z;6UU;#%P,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN
M`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YP<F5I;FET7V%R<F%Y`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N<FES8W8N871T<FEB
M=71E<P``````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````'`"
M````````<`(````````A`````````````````````0``````````````````
M`!,````'`````@````````"4`@```````)0"````````)```````````````
M``````0````````````````````F````!P````(`````````N`(```````"X
M`@```````"`````````````````````$````````````````````-````/;_
M_V\"`````````-@"````````V`(```````"4`0````````4`````````"```
M`````````````````#X````+`````@````````!P!````````'`$````````
M8`D````````&`````@````@`````````&`````````!&`````P````(`````
M````T`T```````#0#0```````,@$```````````````````!````````````
M````````3@```/___V\"`````````)@2````````F!(```````#(````````
M``4``````````@`````````"`````````%L```#^__]O`@````````!@$P``
M`````&`3````````8``````````&`````@````@```````````````````!J
M````!`````(`````````P!,```````#`$P```````$`"````````!0``````
M```(`````````!@`````````=`````0```!"```````````6`````````!8`
M``````!`!0````````4````4````"``````````8`````````'D````!````
M!@````````!`&P```````$`;````````H`,``````````````````!``````
M````$`````````!^`````0````8`````````X!X```````#@'@```````-@M
M```````````````````$````````````````````A`````$````"````````
M`+A,````````N$P```````!W00``````````````````"```````````````
M`````(P````!`````@`````````PC@```````#".````````[```````````
M``````````0```````````````````":`````0````(`````````((\`````
M```@CP```````'`&```````````````````(````````````````````I```
M`!`````#`````````("K````````@)L````````(````````````````````
M`0`````````(`````````+,````.`````P````````"(JP```````(B;````
M````"`````````````````````@`````````"`````````"_````#P````,`
M````````D*L```````"0FP````````@````````````````````(````````
M``@`````````RP````8````#`````````)BK````````F)L````````@`@``
M``````8`````````"``````````0`````````-0````!`````P````````"X
MK0```````+B=````````2`(```````````````````@`````````"```````
M``#9`````0````,``````````+``````````H````````%``````````````
M```````(````````````````````WP````@````#`````````%"P````````
M4*`````````H````````````````````"````````````````````.0````!
M````,````````````````````%"@````````&P````````````````````$`
M`````````0````````#M`````P``<`````````````````````!KH```````
M`%,````````````````````!`````````````````````0````,`````````
M````````````````OJ````````#_`````````````````````0``````````
'````````````
